==> OpenCL-0.8.5.tgz: OpenCL-0.8.5/src/pk_misc.cpp <==
/*************************************************
* Miscellaneous PK Functions Source File         *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#include <opencl/pk_misc.h>

namespace OpenCL {

/*************************************************
* Encode a message                               *
*************************************************/
SecureVector<byte> EME::encode(const byte msg[], u32bit msg_len,
                               u32bit key_bits) const
   {
   return pad(msg, msg_len, key_bits);
   }

/*************************************************
* Encode a message                               *
*************************************************/
SecureVector<byte> EME::encode(const SecureVector<byte>& msg,
                               u32bit key_bits) const
   {
   return pad(msg, msg.size(), key_bits);
   }

/*************************************************
* Decode a message                               *
*************************************************/
SecureVector<byte> EME::decode(const byte msg[], u32bit msg_len,
                               u32bit key_bits) const
   {
   return unpad(msg, msg_len, key_bits);
   }

/*************************************************
* Decode a message                               *
*************************************************/
SecureVector<byte> EME::decode(const SecureVector<byte>& msg,
                               u32bit key_bits) const
   {
   return unpad(msg, msg.size(), key_bits);
   }

/*************************************************
* Signature encoding                             *
*************************************************/
SecureVector<byte> EMSA::encoding(u32bit key_len)
   {
   SecureVector<byte> raw = raw_data();
   return encoding_of(raw, raw.size(), key_len);
   }

/*************************************************
* Signature decoding                             *
*************************************************/
bool EMSA::is_valid_encoding(const byte coded[], u32bit coded_len,
                             const byte raw[], u32bit raw_len,
                             u32bit key_len) throw()
   {
   try {
      return verify(coded, coded_len, raw, raw_len, key_len);
   }
   catch(...)
      {
      return false;
      }
   }

/*************************************************
* Signature decoding                             *
*************************************************/
bool EMSA::is_valid_encoding(const SecureVector<byte>& coded,
                             const SecureVector<byte>& raw,
                             u32bit key_len) throw()
   {
   try {
      return verify(coded, coded.size(), raw, raw.size(), key_len);
   }
   catch(...)
      {
      return false;
      }
   }

/*************************************************
* Default signature decoding                     *
*************************************************/
bool EMSA::verify(const byte coded[], u32bit coded_len,
                  const byte raw[], u32bit raw_len,
                  u32bit key_len)
   {
   try {
      SecureVector<byte> encoded = encoding_of(raw, raw_len, key_len);

      if(encoded.size() != coded_len)
         return false;

      return (cmp_mem(encoded.ptr(), coded, encoded.size()) == 0);
      }
   catch(Invalid_Argument)
      {
      return false;
      }
   }

/*************************************************
* Derive a key                                   *
*************************************************/
SymmetricKey KDF::derive_key(const byte in[], u32bit in_len,
                             u32bit key_len) const
   {
   return derive(in, in_len, key_len);
   }

/*************************************************
* Derive a key                                   *
*************************************************/
SymmetricKey KDF::derive_key(const SecureVector<byte>& in,
                             u32bit key_len) const
   {
   return derive(in, in.size(), key_len);
   }

}

==> OpenCL-0.9.0.tgz: OpenCL-0.9.0/src/pk_misc.cpp <==
/*************************************************
* Miscellaneous PK Functions Source File         *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#include <opencl/pk_misc.h>

namespace OpenCL {

/*************************************************
* Encode a message                               *
*************************************************/
SecureVector<byte> EME::encode(const byte msg[], u32bit msg_len,
                               u32bit key_bits) const
   {
   return pad(msg, msg_len, key_bits);
   }

/*************************************************
* Encode a message                               *
*************************************************/
SecureVector<byte> EME::encode(const SecureVector<byte>& msg,
                               u32bit key_bits) const
   {
   return pad(msg, msg.size(), key_bits);
   }

/*************************************************
* Decode a message                               *
*************************************************/
SecureVector<byte> EME::decode(const byte msg[], u32bit msg_len,
                               u32bit key_bits) const
   {
   return unpad(msg, msg_len, key_bits);
   }

/*************************************************
* Decode a message                               *
*************************************************/
SecureVector<byte> EME::decode(const SecureVector<byte>& msg,
                               u32bit key_bits) const
   {
   return unpad(msg, msg.size(), key_bits);
   }

/*************************************************
* Default signature decoding                     *
*************************************************/
bool EMSA::verify(const SecureVector<byte>& coded,
                  const SecureVector<byte>& raw,
                  u32bit key_len) throw()
   {
   try {
      return (coded == encoding_of(raw, key_len));
      }
   catch(Invalid_Argument)
      {
      return false;
      }
   }

/*************************************************
* Derive a key                                   *
*************************************************/
SymmetricKey KDF::derive_key(const byte in[], u32bit in_len,
                             u32bit key_len) const
   {
   return derive(in, in_len, key_len);
   }

/*************************************************
* Derive a key                                   *
*************************************************/
SymmetricKey KDF::derive_key(const SecureVector<byte>& in,
                             u32bit key_len) const
   {
   return derive(in, in.size(), key_len);
   }

}
